@@ -1,10 +1,37 @@
 package App::DistUtils;
 
-our $DATE = '2014-12-29'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-03-20'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 
+our %dist_arg_single = (
+    dist => {
+        schema => 'str*',
+        req => 1,
+        pos => 0,
+        completion => sub {
+            require Complete::Dist;
+            my %args = @_;
+            Complete::Dist::complete_dist(word=>$args{word});
+        },
+    },
+);
+
+our %dist_arg_multiple = (
+    dist => {
+        schema => ['array*', of=>'str*', min_len=>1],
+        req => 1,
+        pos => 0,
+        greedy => 1,
+        element_completion => sub {
+            require Complete::Dist;
+            my %args = @_;
+            Complete::Dist::complete_dist(word=>$args{word});
+        },
+    },
+);
+
 1;
 # ABSTRACT: Collection of utilities related to Perl distributions
 
@@ -20,7 +47,7 @@ App::DistUtils - Collection of utilities related to Perl distributions
 
 =head1 VERSION
 
-This document describes version 0.05 of App::DistUtils (from Perl distribution App-DistUtils), released on 2015-12-29.
+This document describes version 0.06 of App::DistUtils (from Perl distribution App-DistUtils), released on 2015-03-20.
 
 =head1 SYNOPSIS
 
@@ -53,7 +80,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
